import userApi from '@/api/modules/user.js'

const user = {
	state: {
		tokenObj: {
			token: '',
			date: 0
		},
		userInfo: '',
		name: '',
		avatar: '',
		roles: [],
		permissions: []
	},
	mutations: {
		SET_TOKENOBJ: (state, tokenObj) => {
			state.tokenObj = tokenObj
		},
		REFRESH_TOKEN(state) {
			if (state.tokenObj.token !== '')
				state.tokenObj.date = new Date().getTime()
		},
		SET_USERINFO: (state, userInfo) => {
			state.userInfo = userInfo
		},
		SET_NAME: (state, name) => {
			state.name = name
		},
		SET_AVATAR: (state, avatar) => {
			state.avatar = avatar
		},
		SET_ROLES: (state, roles) => {
			state.roles = roles
		},
		SET_PERMISSIONS: (state, permissions) => {
			state.permissions = permissions
		}
	},
	actions: {
		/**
		 * 用户登录储存token
		 * @param {Object} store
		 */
		async Login(store) {
			wx.showLoading({
			  title: '登陆中...',
			})
			let res = await userApi.login()
			store.commit('SET_TOKENOBJ', {
				token: res.data.token,
				date: new Date().getTime()
			})
			wx.hideLoading()
			return res
		},
		async getToken(store) {
			let tokenObj = store.state.tokenObj
			if (new Date().getTime() - tokenObj.date < 1000 * 60 * 28) {
				return tokenObj.token
			} else {
				let res = await store.dispatch("Login")
				store.commit('SET_TOKENOBJ', {
					token: res.data.token,
					date: new Date().getTime()
				})
				return res.data.token
			}
		},
		/**
		 * 获取用户信息
		 * @param {Object} store
		 */
		async GetInfo(store) {
			let res = await userApi.getInfo()
			store.commit('SET_USERINFO', res.data.student)
			return res
		}
	}
}

export default user
